Welcome to SCALib
=================

.. image:: https://badge.fury.io/py/scalib.svg
    :target: https://badge.fury.io/py/scalib
.. image:: https://readthedocs.org/projects/scalib/badge/?version=stable
    :target: https://scalib.readthedocs.io/en/stable/
    :alt: Documentation Status

The Side-Channel Analysis Library (SCALib) is a Python package that
contains state-of-the-art tools for side-channel evaluation. It focuses on
providing efficient implementations of analysis methods widely used by the
side-channel community and maintaining a flexible and simple interface.

SCALib contains various features for side-channel analysis, see the documentation_.

.. _documentation: https://scalib.readthedocs.io/en/stable

Install
=======

SCALib is on PyPi!

.. code-block::

    pip install scalib

See install_ for details.
 
.. _install: https://scalib.readthedocs.io/en/stable/index.html#install


About us
========
SCALib has been initiated by Olivier Bronchain during his PhD at Crypto Group,
UCLouvain, Belgium. His colleague Gaëtan Cassiers co-authored SCALib. The SCALib
project is part of `SIMPLE-Crypto <https://www.simple-crypto.dev/>`_ and is
maintained in that context.

Contributions and Issues
========================

See contribution_ and `DEVELOP.rst <DEVELOP.rst>`_.

.. _contribution: https://scalib.readthedocs.io/en/stable/index.html#contributions-and-issues

License
=======
This project is licensed under `GNU AFFERO GENERAL PUBLIC LICENSE, Version 3`.
See `COPYING <COPYING>`_ for more information.
